# Novel Observing Strategies Testbed (NOS-T)

The Novel Observing Strategies Testbed (NOS-T) is a computational testbed for
maturing technologies related to the NASA Novel Observing Strategies thrust.

Documentation: https://nost-tools.readthedocs.io

## NOS-T Tools Installation

NOS-T tools is a collection of tools for the Novel Observing Strategies Testbed
(NOS-T). Installing `nost-tools` as an editable Python library requires `pip`
version 23 or greater (install via `python -m pip install --upgrade pip`).

To install `nost-tools`, run the following command from the project root
directory:

```
pip install -e .
```

Alternatively, to install supplemental libraries required for examples, run

```
pip install -e .[examples]
```

## Contact

Principal Investigator: Paul T. Grogan <paul.grogan@asu.edu>

## Acknowledgements

This material is based on work supported, in whole or in part, by the U.S.
Department of Defense and National Aeronautics and Space Administration Earth
Science Technology Office (NASA ESTO) through the Systems Engineering Research
Center (SERC) under Contract No. W15QKN-18-D-0040. SERC is a federally funded
University Affiliated Research Center managed by Stevens Institute of
Technology. Any opinions, findings, and conclusions or recommendations
expressed in this material are those of the authors and do not necessarily
reflect the views of the United States Department of Defense.

This research has made use of NASA Goddard Science Managed Cloud Environment 
(SMCE), which is a service of the Computational & Information Sciences and 
Technology Office at the NASA Goddard Space Flight Center.

Current project team:

- PI: Paul T. Grogan <paul.grogan@asu.edu>
- Research Scientist: Emmanuel M. Gonzalez <emmanuelgonzalez@asu.edu>

Project alumni:

- Hayden Daly
- Matthew Brand
- Jerry Sellers
- Brian Chell
- Matthew LeVine
- Leigha Capra
- Theodore Sherman
- Alex Yucra Castaneda
